@@ -1,8 +1,5 @@
 import os
-
-
-def normalize_path(path):
-    return os.path.abspath(os.path.expanduser(path))
+from utils import normalize_path
 
 
 def ensure(links, basedir):
